# fcdproc

Python package to detect FCD lesions in MRI negative epilepsy patients

## Installation

```bash
$ pip install fcdproc
```

## Usage

- TO DO:


## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`fcdproc` was created by InatiLab. It is licensed under the terms of the GNU General Public License v3.0 license.

## Credits
